sequencetools.replace_sequence_elements_cyclically_with_new_material
====================================================================

.. autofunction:: abjad.tools.sequencetools.replace_sequence_elements_cyclically_with_new_material.replace_sequence_elements_cyclically_with_new_material
